@@ -1,10 +1,9 @@
 import argparse
 import logging
-from urllib.parse import urlparse
 
 from cook import util, http, metrics, version, configuration
-from cook.subcommands import submit, show, wait, jobs, ssh, ls, tail, kill, config, cat, usage
-from cook.util import deep_merge
+from cook.subcommands import admin, cat, config, jobs, kill, ls, show, ssh, submit, tail, usage, wait
+from cook.util import deep_merge, load_target_clusters
 import cook.plugins
 
 parser = argparse.ArgumentParser(description='cs is the Cook Scheduler CLI')
@@ -20,6 +19,7 @@ parser.add_argument('--version', help='output version information and exit',
 subparsers = parser.add_subparsers(dest='action')
 
 actions = {
+    'admin': admin.register(subparsers.add_parser, configuration.add_defaults),
     'cat': cat.register(subparsers.add_parser, configuration.add_defaults),
     'config': config.register(subparsers.add_parser, configuration.add_defaults),
     'jobs': jobs.register(subparsers.add_parser, configuration.add_defaults),
@@ -34,30 +34,6 @@ actions = {
 }
 
 
-def load_target_clusters(config_map, url=None, cluster=None):
-    """Given the config and (optional) url and cluster flags, returns the list of clusters to target"""
-    if cluster and url:
-        raise Exception('You cannot specify both a cluster name and a cluster url at the same time')
-
-    clusters = None
-    config_clusters = config_map.get('clusters')
-    if url:
-        if urlparse(url).scheme == '':
-            url = 'http://%s' % url
-        clusters = [{'name': url, 'url': url}]
-    elif config_clusters:
-        if cluster:
-            clusters = [c for c in config_clusters if c.get('name').lower() == cluster.lower()]
-            if len(clusters) == 0 and len(config_clusters) > 0:
-                config_cluster_names = ', '.join([c.get('name') for c in config_clusters])
-                raise Exception(f'You specified cluster {cluster}, which was not present in your config.' +
-                                f' You have the following clusters configured: {config_cluster_names}.')
-        else:
-            clusters = [c for c in config_clusters if 'disabled' not in c or not c['disabled']]
-
-    return clusters
-
-
 def run(args, plugins):
     """
     Main entrypoint to the cook scheduler CLI. Loads configuration files, 
